CONTENTS OF THIS FILE
=====================

 * Introduction
 * Requirements
 * Optional Modules
 * Installation
 * Configuration
 * Advanced Configuration
 * Permissions
 * Performance
 * EXML Feed
 * Related Modules
 * Maintainers


INTRODUCTION
============

The Evanced Events Importer module imports and syncs data from Evanced
Solutions' Events/SignUp calendar product with your Drupal site.

Evanced Events Importer maps elements from your Evanced calendar's built-in EXML
feed to fields in a Drupal content type to create nodes for each published event
in Evanced Events/SignUp. When the Evanced calendar is updated in Evanced
Events/SignUp and cron runs in Drupal, the module keeps the events in sync
using the Evanced ID assigned to each event. The module also deletes nodes that
are unpublished or deleted in the Evanced Events/SignUp calendar, provided they
fall within the date range covered by the EXML feed.

With this module installed you can continue to use Evanced Events/SignUp as a
stand-alone product to create events, manage event registration, record
attendance statistics, run reports and manage room reservations
(in conjunction with Room Reserve/Spaces/D!BS), but you can also take
advantage of all the power of Drupal and the Views module to create multiple
displays of your events across your website.


REQUIREMENTS
============

 * Subscription to Events or SignUp by [Evanced Solutions](http://evancedsolutions.com)
 * Core Date module enabled
 * Basic familiarity with content types and views


OPTIONAL MODULES
================

 * [Address](https://www.drupal.org/project/address)  
   Evanced Events Importer may be configured to parse addresses. After
   installing the Address module, follow the instructions below ("Mapping and
   displaying address data").


INSTALLATION
============

Install as you would normally install a contributed Drupal module. For more
information, see [Installing contributed modules](https://www.drupal.org/documentation/install/modules-themes/modules-8).


CONFIGURATION
=============

Administration > Structure > Content types
------------------------------------------

Create a content type for your events.

Required fields:

 * **Start date/time** [see note below]  
   field type: datetime (1 value)
 * **Evanced ID**  
   field type: integer (1 value)

Recommended fields:

 * **End date/time** [see note below]  
   field type: datetime (1 value)

Suggested fields:

 * **Location**  
   field type: entity reference (unlimited values)
 * **Audience**  
   field type: entity reference (unlimited values)
 * **Event type**  
   field type: entity reference (unlimited values)

Note: In Drupal 8, the Date module has been moved to core. As of 8.1, the core
Date module does not offer support for end dates. To include end times for
your events, you must create two separate datetime fields in Drupal that must be
mapped to the Evanced EXML feed in a specific way. Review the notes on field
mapping below.

Work is currently in progress to create a separate module for date ranges that
may be a better fit for this module: [Support for end date](https://www.drupal.org/node/2161337).
Future releases of Evanced Events Importer may be refactored to work with any
date range module that may be released.

Administration > Structure > Taxonomy
-------------------------------------

Create vocabularies that correspond with the Branch Specific Lists
and System Wide Lists in Evanced Events/SignUp.

Suggested vocabularies:

 * Location
 * Event type
 * Age group

Associate each vocabulary with your event content type.

Administration > Configuration > Evanced Events Importer
--------------------------------------------------------

Configure the Evanced Events Importer module.

The "Main configuration" tab allows you to set basic
configuration settings, including:

 * Under "EXML feed URL," supply the URL from your Evanced Events/SignUp
   installation. Refer to the Evanced Knowledge Base for available "switches"
   to customize the feed URL
 * For "Content type," select the content type you want to use for event
 * For "Event author," enter the Drupal user ID of the account that will be
   set as the author of events.
 * Check the box for "Log automatic creation, update and deletion of events"
   if you want Drupal to record all changes to events in the Drupal log.
 * Check the box for "Force update of existing Drupal events" if you want
   Drupal to overwrite all existing events with content from the EXML feed.
   Otherwise, only events with a newer timestamp in the EXML feed will
   be updated.
 * For "Input format," select the input format that will be applied to the
   main body for your event content type.
 * For "Relative link domain," enter a domain name to be used to convert
   absolute links found in the event description into relative links. Leave
   blank if you do not want to convert absolute links to relative links.
 * Check the box for "Strip all links from the event description" if you want
   to remove all link (a href) tags from the EXML event description. No other
   HTML tags will be removed.

The "XML mapper" tab allows you to map elements from the Evanced Events/SignUp
EXML feed to the fields of your event content type in Drupal.

 * To map EXML element(s) to a Drupal field, select the element(s) on the
   left and click the button with the right arrow ( > ) next to the field
   you want to map it to.
 * To unmap EXML element(s) from a Drupal field, select the element(s) on
   the right and click the button with the left arrow ( < ) next to the field
   you want to remove the element from.
 * To see an example of a mapping configuration, click the "Example
   mappings" link.
 * To map start and end times, use the "time" and "endtime" EXML elements
   to map to your Drupal start date and end date fields.  It is not necessary
   to map the "date1" and "enddate1" elements. The event date(s) will be
   automatically derived and mapped to your fields.
 * To save your mappings, click the "Save configuration" button.

The "Sync events" tab offers the option to manually sync your events without
the overhead that comes with a full cron run.


ADVANCED CONFIGURATION
======================

Using taxonomy synonyms to modify text display
----------------------------------------------

When mapping an Evanced EXML element to a Drupal taxonomy vocabulary, you may
wish to display text on your website that is different from text used in
Evanced Events/SignUp. For example, in Evanced Events/SignUp you might prepend
room names with a building name, but might want to display room names without
building names in Drupal.

To modify the text display, add a text field to your taxonomy vocabulary with a
machine name that includes "synonym" (e.g., location\_synonym, synonym\_evanced).
Use the text you want to display on your Drupal site as the taxonomy term's
name. Enter the text used in Evanced Events/SignUp in your synonym field.

Mapping and displaying address data
-----------------------------------

If you offer events at locations other than your library branches, you may
wish to display full addresses. Evanced Events Importer can be configured to
work with the Address module to parse addresses. (Note that address parsing is
currently only configured to work with US addresses.)

You will need to use the "Other Info" field in Evanced Events/SignUp to enter
addresses. (The Evanced Events/SignUp field used to enter addresses must be a
text area with multiple lines and must also appear in the EXML feed.)

After installing the Address module, add a field with the type "Address" in
your event content type. Map the "otherinfo" EXML element to the address field
on your content type.

To be parsed correctly as an address, the data entered into Evanced
Events/SignUp's "Other Info" field must be entered in a specific format,
using either two or three lines, depending on whether you want to include
a location name:

1234 Community Way  
Librarytown, OH 45678

Librarytown Community Center  
1234 Community Way  
Librarytown, OH 45678

 * To include a location name, include it first, on its own line
 * Street address must be entered on its own line
 * City, state and ZIP code must be entered on its own line as: city comma
   state space ZIP code
 * Use the two-character postal abbreviation for the state, territory
   or district
 * Both 5- and 9-digit ZIP codes are acceptable

 
PERMISSIONS
===========

By default, ony users with the Administrator role can access Evanced Events
Importer functions. These can be granted to non-administrators by granting one
or more of the following permissions to users' roles.

Configure Evanced Events Importer
---------------------------------

This permission will allow a user to access the module's configuration tabs
("Main configuration," "XML mapper," and "Sync events").

Run Evanced Events Importer
---------------------------

This permission will allow a user to manually initiate processing the EXML
feed to create, update or delete events in Drupal.


PERFORMANCE
===========

Initial Cron Run
----------------

When cron is running, the Evanced Events Importer checks to see if an existing
event in Drupal needs to be updated - and quickly moves past it if it doesn't.
The most time-consuming thing the module does is create new event nodes.

With this in mind: the first time you use the Evanced Events Importer, you
may have a lot of new event data to import, which will be a time-consuming
process. If you import all that data at once, you may hit PHP's Max Execution
Time limit (i.e., 'max\_execution\_time' in your php.ini file) before cron
can finish executing.

To avoid overtaxing the system during your first import, we recommend that
you configure your EXML feed URL so that it lists only a month's worth of data
the first time (see "EXML Feed Parameters" below). After cron has run
successfully, expand the time period to two months (or three, if you don't
have that many events scheduled in the future). Manually run cron again.
Continue to do this until you've imported all your desired data. From that
point on, you should be able to set the Evanced Events Importer to import
events up to 365 days in the future without causing any problems. Note: This
may vary depending on how many other tasks are hooked into cron on your Drupal
installation, or the number of events in your EXML feed.


EXML FEED
=========

Evanced provides various XML feeds for exporting data from its Events
software. Their EXML feed includes the most robust event data, which is why
it is the feed of choice for this module. The other feeds offered by Evanced
(xml, rss2, atom1, ical) are more compact and don't include certain fields, such
as event end times and/or specific categories (Event Types, Age Groups, etc.).

EXML Feed Location
------------------

Depending on your installation of Evanced Events/SignUp,
you should find the EXML feed here:
[url\_of\_your\_evanced\_installation]/eventsxml.asp?dm=exml

EXML Feed Parameters
---------------------

You can add parameters to the feed URL to control the scope of the data
displayed. For example, the nd parameter controls the number of days included
in the EXML feed  (e.g., "nd=30" means "show events coming up in the next
30 days").

You can find a description of all the parameters for configuring the feed in
the Evanced Knowledge Base. Note that Evanced refers to the available
parameters as "switches."

 * For Events, see [Creating XML-RSS Feeds](http://kb.evanced.info/article.php?id=77)
 * For SignUp, see [SignUp - Events XML Feed URL Variables](http://kb.evanced.info/article.php?id=482)

Consult your Evanced representative if you need help with accessing or
configuring the EXML feed or Events software.


RELATED MODULES
===============

Registration
------------

This module does not include functionality related to patron registration. You
may be interested in the [Evanced Registration module](https://www.drupal.org/project/evanced_registration).

Evanced Solutions SignUp
------------------------

Evanced Solutions has released SignUp as a successor to its Events product.
Despite the differences between SignUp and Events, the EXML feed remains the
same. The Evanced Events Importer is compatible with both products,
[as tested and confirmed by the Drupal community](http://drupal.org/node/2188063#comment-9702515).


MAINTAINERS
===========

 * **Stefan Langer** (slanger) - [slanger@worthingtonlibraries.org](mailto:slanger@worthingtonlibraries.org)
 * **Joseph Kovell** (jkovell) - [jkovell@worthingtonlibraries.org](mailto:jkovell@worthingtonlibraries.org)
 * **Kara Reuter** (kittysunshine) - [kreuter@worthingtonlibraries.org](mailto:kreuter@worthingtonlibraries.org)

This module was originally created in 2009 by Worthington Libraries for their [website](http://www.worthingtonlibraries.org).
