<?php

namespace Drupal\evanced_events_importer\Form;

use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\evanced_events_importer\Controller\Importer;
use Drupal\evanced_events_importer\Controller\Configuration;

/**
 * Define Evanced Events Importer Sync Events form.
 */
class SyncEventsForm extends FormBase {

  /**
   * Return form ID.
   */
  public function getFormId() {
    return 'evanced_events_importer_sync_events';
  }

  /**
   * Build form.
   *
   * @param array $form
   *   Form data.
   * @param FormStateInterface $form_state
   *   Form state.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    // Get configuration settings.
    $config = Configuration::getConfigurationSettings();

    // Create array to hold form structure.
    $form = [];

    // If an XML feed_url and field_map are defined...
    if (($config['feed_url'] != '') && !empty($config['field_map'])) {

      $form['summary'] = [
        '#type' => 'markup',
        '#markup' => '<p>Your Drupal events are automatically synced with Evanced Events every time cron runs. Run “Sync events” to manually sync your events independently from cron.</p>',
      ];

      $form['buttons']['submit'] = [
        '#type' => 'submit',
        '#value' => t('Sync events'),
      ];

    }
    else {

      $message =
      t('To sync events, you must first configure this module. @internal-url-settings that comes with your Evanced Events installation and @internal-mapping-settings.',
        [
          '@internal-url-settings' => Link::fromTextAndUrl(
            'Enter the EXML feed URL',
            Url::fromRoute('evanced_events_importer.main_configuration_form')
          )->toString(),
          '@internal-mapping-settings' => Link::fromTextAndUrl(
            'map the XML data',
            Url::fromRoute('evanced_events_importer.xml_mapper_form')
          )->toString(),
        ]
      );

      // Display a message, instructing the user to enter an XML feed first.
      drupal_set_message($message, 'warning');

    }

    return $form;

  }

  /**
   * Process form data upon submission.
   *
   * @param array $form
   *   Form data.
   * @param FormStateInterface $form_state
   *   Form state.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    // Update events.
    Importer::updateEvents();

    // Ensure that a confirmation message is displayed.
    drupal_set_message(t('Your Evanced Events have been synced.'), 'status');

  }

}
